abacusai.project_validation — AbacusAI documentation

# abacusai.project_validation

## Classes

`ProjectValidation` | A validation result for a project

## Module Contents

class abacusai.project_validation.ProjectValidation(client, valid=None, datasetErrors=None, columnHints=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A validation result for a project

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - valid (bool) – true if the project is valid and ready to be trained, otherwise false.

    - datasetErrors (list[dict]) – A list of errors keeping the dataset from being valid

    - columnHints (dict) – Hints for what to set on the columns

  valid = None
  dataset_errors = None
  column_hints = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict